@@ -1033,7 +1033,7 @@ void Script::strict::createSym(Script* image, Script::header *scr, const char *i
     if(scr && !image->global)
         return;
 
-    if(*(scr->name) != '@') {
+    if(scr && *(scr->name) != '@') {
         sp = scr->scoped;
         while(is(sp)) {
             if(ideq(sp->id, id))
@@ -1067,7 +1067,7 @@ void Script::strict::createAny(Script* image, Script::header *scr, const char *i
     if(scr && !image->global)
         return;
 
-    if(*(scr->name) != '@') {
+    if(scr && *(scr->name) != '@') {
         sp = scr->scoped;
         while(is(sp)) {
             if(ideq(sp->id, id))
@@ -1082,7 +1082,7 @@ void Script::strict::createAny(Script* image, Script::header *scr, const char *i
         sp.next();
     }
     sym = (Script::strict *)image->zalloc(sizeof(Script::strict));
-    if(*(scr->name) != '@')
+    if(scr && *(scr->name) != '@')
         sym->enlist(&scr->scoped);
     else
         sym->enlist(&image->global);
